==> assertj-build-3.25.3.tar.gz: assertj-assertj-build-3.25.3/assertj-core/src/test/java/org/assertj/core/internal/AbstractTest_ComparatorBasedComparisonStrategy.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2024 the original author or authors.
 */
package org.assertj.core.internal;

import java.util.Comparator;

import org.assertj.core.test.CaseInsensitiveStringComparator;

public class AbstractTest_ComparatorBasedComparisonStrategy {

  protected Comparator<String> caseInsensitiveStringComparator = CaseInsensitiveStringComparator.INSTANCE;
  protected ComparatorBasedComparisonStrategy caseInsensitiveComparisonStrategy = new ComparatorBasedComparisonStrategy(
                                                                                                                        caseInsensitiveStringComparator);
  protected ComparatorBasedComparisonStrategy describedComparisonStrategy = new ComparatorBasedComparisonStrategy(
                                                                                                                  caseInsensitiveStringComparator,
                                                                                                                  "Case-insensitive comparator for String class");

}

==> assertj-build-3.27.6.tar.gz: assertj-assertj-build-3.27.6/assertj-core/src/test/java/org/assertj/core/internal/AbstractTest_ComparatorBasedComparisonStrategy.java <==
/*
 * Licensed under the Apache License, Version 2.0 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software distributed under the License is distributed on
 * an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations under the License.
 *
 * Copyright 2012-2025 the original author or authors.
 */
package org.assertj.core.internal;

import java.util.Comparator;

import org.assertj.core.testkit.CaseInsensitiveStringComparator;

public class AbstractTest_ComparatorBasedComparisonStrategy {

  protected Comparator<String> caseInsensitiveStringComparator = CaseInsensitiveStringComparator.INSTANCE;
  protected ComparatorBasedComparisonStrategy caseInsensitiveComparisonStrategy = new ComparatorBasedComparisonStrategy(
                                                                                                                        caseInsensitiveStringComparator);
  protected ComparatorBasedComparisonStrategy describedComparisonStrategy = new ComparatorBasedComparisonStrategy(
                                                                                                                  caseInsensitiveStringComparator,
                                                                                                                  "Case-insensitive comparator for String class");

}
